@@ -28,7 +28,6 @@
 #include <Item>
 #include <QDialog>
 #include <KCalCore/Incidence>
-#include <KDateTime>
 
 #include <QPoint>
 #include <QTimer>
@@ -60,7 +59,19 @@ class QSpinBox;
 class AlarmDialog : public QDialog
 {
     Q_OBJECT
+    Q_ENUMS(SuspendUnit)
+
 public:
+    /**
+     * The suspend time unit.
+     */
+    enum SuspendUnit {
+        SuspendInMinutes = 0,  ///< Suspend time is in minutes
+        SuspendInHours   = 1,  ///< Suspend time is in hours
+        SuspendInDays    = 2,  ///< Suspend time is in days
+        SuspendInWeeks   = 3   ///< Suspend time is in weeks
+    };
+
     explicit AlarmDialog(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *parent = nullptr);
     ~AlarmDialog();
 
@@ -103,7 +114,7 @@ private:
     void updateButtons();
     typedef QList<ReminderTreeItem *> ReminderList;
 
-    static KDateTime triggerDateForIncidence(const KCalCore::Incidence::Ptr &inc,
+    static QDateTime triggerDateForIncidence(const KCalCore::Incidence::Ptr &inc,
             const QDateTime &reminderAt,
             QString &displayStr);
 
@@ -126,19 +137,19 @@ private:
     void showDetails(QTreeWidgetItem *item);
 
     Akonadi::ETMCalendar::Ptr mCalendar;
-    QTreeWidget *mIncidenceTree;
-    CalendarSupport::IncidenceViewer *mDetailView;
-    KIdentityManagement::IdentityManager *mIdentityManager;
+    QTreeWidget *mIncidenceTree = nullptr;
+    CalendarSupport::IncidenceViewer *mDetailView = nullptr;
+    KIdentityManagement::IdentityManager *mIdentityManager = nullptr;
 
     QPoint mPos;
-    QSpinBox *mSuspendSpin;
-    KComboBox *mSuspendUnit;
+    QSpinBox *mSuspendSpin = nullptr;
+    KComboBox *mSuspendUnit = nullptr;
     QTimer mSuspendTimer;
-    QTreeWidgetItem *mLastItem;
-    QPushButton *mUser1Button;
-    QPushButton *mUser2Button;
-    QPushButton *mUser3Button;
-    QPushButton *mOkButton;
+    QTreeWidgetItem *mLastItem = nullptr;
+    QPushButton *mUser1Button = nullptr;
+    QPushButton *mUser2Button = nullptr;
+    QPushButton *mUser3Button = nullptr;
+    QPushButton *mOkButton = nullptr;
 
 };
 
